cli

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: 0BSD Imports: 40 Imported by: 0

Documentation

Overview

Package cli owns Glippy command dispatch and process-facing I/O contracts.

Index

Constants

const (
	ExitSuccess           = 0
	ExitFindings          = 1
	ExitSourceError       = 2
	ExitInvalidInvocation = 3
	ExitConflict          = 4
	ExitFilesystemError   = 5
	ExitInternalError     = 6
	ExitCanceled          = 130
)

Variables

This section is empty.

Functions

func Run

func Run(arguments []string, stdin io.Reader, stdout, stderr io.Writer) int

Run executes one Glippy invocation against explicit process streams.

func RunContext

func RunContext(
	ctx context.Context,
	arguments []string,
	stdin io.Reader,
	stdout, stderr io.Writer,
) int

RunContext executes one Glippy invocation and observes cancellation between bounded operations.

Types

This section is empty.

Jump to