format

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: 0BSD Imports: 10 Imported by: 0

Documentation

Overview

Package format lowers Go syntax into the Glippy document model.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func File

func File(file *source.File, options Options) ([]byte, error)

File formats one valid immutable source unit.

func Fragment

func Fragment(fragment *source.Fragment, options Options) ([]byte, error)

Fragment formats one valid source fragment at its explicitly selected AST boundary.

Types

type Options

type Options struct {
	Width     int
	TabWidth  int
	FitBudget int
}

Options controls deterministic formatting.

Directories

Path Synopsis
Package doc provides the language-neutral document model used by the Glippy formatter.
Package doc provides the language-neutral document model used by the Glippy formatter.

Jump to