package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Aug 27, 2026
License: 0BSD
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package discovery owns deterministic filesystem input selection.
File is one normalized Go source selected from an immutable discovery pass.
GoFiles returns normalized Go source paths in deterministic order.
type Options struct {
Root string
}
Options defines the authorized recursive discovery boundary.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.