package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Aug 27, 2026
License: 0BSD
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package format lowers Go syntax into the Glippy document model.
File formats one valid immutable source unit.
Fragment formats one valid source fragment at its explicitly selected AST
boundary.
type Options struct {
Width int
TabWidth int
FitBudget int
}
Options controls deterministic formatting.
Source Files
¶
Directories
¶
Package doc provides the language-neutral document model used by the Glippy formatter.
|
Package doc provides the language-neutral document model used by the Glippy formatter. |
Click to show internal directories.
Click to hide internal directories.