Documentation
¶
Overview ¶
Package release builds deterministic prototype release artifacts.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Artifact ¶
type Artifact struct {
File string `json:"file"`
GOOS string `json:"goos"`
GOARCH string `json:"goarch"`
SHA256 string `json:"sha256"`
Size int64 `json:"size"`
}
Artifact records one archived binary and its content identity.
type Manifest ¶
type Manifest struct {
SchemaVersion int `json:"schema_version"`
Product string `json:"product"`
Version string `json:"version"`
SourceRevision string `json:"source_revision"`
GoVersion string `json:"go_version"`
Artifacts []Artifact `json:"artifacts"`
}
Manifest binds release artifacts to source, version, and build toolchain.
Click to show internal directories.
Click to hide internal directories.